@@ -27,11 +27,11 @@ solve_1comp <- function(chem.cas=NULL,
   if(is.null(chem.cas) & is.null(chem.name) & is.null(parameters)) stop('Parameters, chem.name, or chem.cas must be specified.')
   if(is.null(parameters)){  parameters <- parameterize_1comp(chem.name=chem.name,chem.cas=chem.cas,species=species,default.to.human=default.to.human,adjusted.Funbound.plasma=adjusted.Funbound.plasma,regression=regression,restrictive.clearance=restrictive.clearance,well.stirred.correction=well.stirred.correction,suppress.messages=suppress.messages) 
   }else{
-    name.list <- c("Vdist","kelim","kgutabs","Rblood2plasma","MW","million.cells.per.gliver","hematocrit","Fgutabs")
-    if(!all(name.list %in% names(parameters)))stop(paste("Missing parameters:",paste(name.list[which(!name.list %in% names(parameters))],collapse=', '),".  Use parameters from parameterize_1comp."))
+     if(!all(param.names.1comp %in% names(parameters)))stop(paste("Missing parameters:",paste(param.names.1comp[which(!param.names.1comp %in% names(parameters))],collapse=', '),".  Use parameters from parameterize_1comp."))
   }
   Rb2p <- parameters[['Rblood2plasma']]
-  
+  BW <- parameters[['BW']]
+   
   parameters$Fgutabs <- parameters$Fgutabs * parameters$hepatic.bioavailability
 
   if(is.null(times)) times <- round(seq(0, days, 1/(24*tsteps)),8)
@@ -123,7 +123,7 @@ solve_1comp <- function(chem.cas=NULL,
   }
   parameters[['ke']] <- parameters[['kelim']]   
   parameters[['vdist']] <- parameters[['Vdist']]
-  parameters <- initparms1comp(parameters[!(names(parameters) %in% c("kelim","Rblood2plasma","MW",'Vdist','million.cells.per.gliver','hematocrit','Fgutabs','hepatic.bioavailability'))])
+  parameters <- initparms1comp(parameters[param.names.1comp.solver])
   
   state <-initState1comp(parameters,state)
   
@@ -136,17 +136,18 @@ solve_1comp <- function(chem.cas=NULL,
       length <- length(dosing)
       if(iv.dose) eventdata <- data.frame(var=rep('Acompartment',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length))           
       else eventdata <- data.frame(var=rep('Agutlumen',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length)) 
-      times <- sort(c(times,dosing + 1e-8,1e-8))               
+      times <- sort(c(times,dosing + 1e-8,start + 1e-8))               
       out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
     }
   }else{
     if(iv.dose) eventdata <- data.frame(var=rep('Acompartment',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))
     else eventdata <- data.frame(var=rep('Agutlumen',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))                          
-    times <- sort(c(times,dosing.times + 1e-8,1e-8))
+    times <- sort(c(times,dosing.times + 1e-8,start + 1e-8))
     out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
   }
    
-
+  if(use.amounts) out[,c('Agutlumen','Acompartment','Ametabolized')] <- out[,c('Agutlumen','Acompartment','Ametabolized')] * BW
+  else out[,c('Agutlumen','Ametabolized')] <- out[,c('Agutlumen','Ametabolized')] * BW
 
  if(plots==T)
   {
@@ -159,22 +160,21 @@ solve_1comp <- function(chem.cas=NULL,
   if(!suppress.messages){
     if(is.null(chem.cas) & is.null(chem.name)){
       if(use.amounts){
-        cat("Values returned in",output.units,"/ kg BW units.\n")
+        cat("Values returned in",output.units," units.\n")
       }else{
         if(tolower(output.units) == 'um'){
           out.amount <- 'umol'
         }else out.amount <- 'mg'
-        cat("Amounts returned in",out.amount,"/ kg BW and concentration returned in",output.units,"units.\n")
+        cat("Amounts returned in",out.amount," and concentration returned in",output.units,"units.\n")
       }
     }else{
-      if(use.amounts){
-        
-        cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"values returned in",output.units,"/ kg BW units.\n")
+      if(use.amounts){  
+        cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"values returned in",output.units,"units.\n")
       }else{
         if(tolower(output.units) == 'um'){
           out.amount <- 'umol'
         }else out.amount <- 'mg'
-        cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"amounts returned in",out.amount,"/ kg BW and concentration returned in",output.units,"units.\n")
+        cat(paste(toupper(substr(species,1,1)),substr(species,2,nchar(species)),sep=''),"amounts returned in",out.amount,"and concentration returned in",output.units,"units.\n")
       }
     }
     if(tolower(output.units) == 'mg'){
@@ -185,4 +185,4 @@ solve_1comp <- function(chem.cas=NULL,
   }
 
   return(out)
-}
\ No newline at end of file
+}
